# DTPySide

## Installation

Install from PyPI:

`pip install DTPySide`

or build on your own:

`py -m build`

## Try Demo

```python
from DTPySide.demo import main

main.run()
```

# Examples

Some projects made with DTPySide:

- [DongliTeahouseStudio2](https://github.com/Holence/DongliTeahouseStudio2)
- [LifeTimeline](https://github.com/Holence/LifeTimeline)
- [BucketList](https://github.com/Holence/BucketList)
- [WireSock GUI](https://github.com/Holence/WireSock-GUI)
